@@ -306,6 +306,7 @@ class GlobalChemExtensions(object):
             rdkit=True,
             partial_smiles=True,
             pysmiles=True,
+            molvs=True,
             partial=False,
             return_failures=False
     ):
@@ -328,7 +329,8 @@ class GlobalChemExtensions(object):
             smiles_list,
             rdkit=rdkit,
             partial_smiles=partial_smiles,
-            pysmiles=pysmiles
+            pysmiles=pysmiles,
+            molvs=molvs
         )
 
         if return_failures:
